@@ -1,12 +1,21 @@
 # Prompt/Timeout.pm
 #
-# Copyright (c) 2008 Serguei Trouchelle. All rights reserved.
+# $Id: Timeout.pm 26 2010-11-05 12:39:20Z stro $
+#
+# Copyright (c) 2008, 2009 Serguei Trouchelle. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
 # History:
-#  1.00  2008/05/22 Initial revision
+#  1.04_01 2010/11/05 Added more prerequisites to find out what's wrong with some test reports
+#                     Rewrite tests with Test::More
+#  1.03    2010/11/01 Fixed problem with non-working "click", thanks to bottomsc[.]missouri.edu for reporting (RT#62535)
+#                     Fixed potential problem with TAP output parsing
+#  1.02    2009/08/31 Fixed problem with hanging in Unix environment, thanks to leocharre[.]cpan.org for reporting
+#  1.01    2008/05/23 Documentation typo
+#                     Removed Term::ReadKey::ReadMode because it doesn't work on some terminals
+#  1.00    2008/05/22 Initial revision
 
 =head1 NAME
 
@@ -32,7 +41,7 @@ require Exporter;
 our @EXPORT = qw(prompt);
 our @ISA = qw(Exporter);
 
-$Prompt::Timeout::VERSION = "1.00";
+$Prompt::Timeout::VERSION = '1.04_01';
 
 =head1 DESCRIPTION
 
@@ -54,7 +63,7 @@ you can invoke it with another optional parameter:
 
 Once a key is pressed, inactivity timer is disabled.
 
-When $timeout vales is omitted, it assumes 60 seconds.
+When $timeout value is omitted, it assumes 60 seconds.
 
 =cut 
 
@@ -86,23 +95,25 @@ sub prompt ($;$$$) {
 
     my $end = time + $timeout;
 
-    ReadMode 4; # Turn off controls keys
+    #ReadMode 4; # Turn off controls keys
     while (1) {
       my $key = ReadKey(1); # 1 sec
       if (defined $key) {
-        last if $key eq "\r";
+        last if $key =~ /^[\r\n]$/x;
         $ans .= $key;
         print $key;
         $end = time + $timeout;
       } else {
-        if ($end < time and not ($click and $ans ne '')) {
-          $ans = $def;
-          print "$def\n";
-          last;
+        unless ($click and $ans ne '') {
+          if ($end < time) {
+            $ans = $def;
+            print "$def\n";
+            last;
+          }
         }
       }
     }
-    ReadMode 0; # Reset tty mode before exiting
+    #ReadMode 0; # Reset tty mode before exiting
   }
   return (!defined $ans || $ans eq '') ? $def : $ans;
 }
@@ -111,11 +122,11 @@ sub prompt ($;$$$) {
 
 Serguei Trouchelle E<lt>F<stro@railways.dp.ua>E<gt>
 
-FindBin::Real uses partial code from ExtUtils::MakeMaker module.
+Prompt::Timeout uses partial code from ExtUtils::MakeMaker module.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Serguei Trouchelle. All rights reserved.
+Copyright (c) 2008-2010 Serguei Trouchelle. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
